@@ -103,7 +103,6 @@ from vessl.workspace import (
 
 # Expose others
 from vessl.util.image import Image  # isort:skip
-from vessl.util.audio import Audio  # isort:skip
 
 
 # Suppress all exceptions during SDK mode
@@ -131,7 +130,7 @@ for name, value in inspect.getmembers(
     vars()[name] = suppress_sdk_exception(value)
 
 # Other classes that the user may interact with
-user_classes = [Image, Audio]
+user_classes = [Image]
 for user_class in user_classes:
     for name, value in inspect.getmembers(
         user_class, predicate=lambda x: inspect.ismethod(x) or inspect.isfunction(x)
