@@ -1,5 +1,6 @@
 from datetime import datetime
 from typing import Any, Callable, Dict, List, Union
+
 import click
 import inquirer
 from terminaltables import AsciiTable
@@ -79,11 +80,11 @@ def print_data(data: Dict[str, Any]) -> None:
 
 def print_logs(logs: List[Any]):
     timezone = datetime.now().astimezone().tzinfo
-    lines = [
-        f" [{datetime.fromtimestamp(x.timestamp, tz=timezone).strftime('%H:%M:%S.%f')}] {x.message}"
-        for x in logs
-    ]
-    print("\n".join(lines))
+    for log in logs:
+        ts = datetime.fromtimestamp(log.timestamp, tz=timezone).strftime('%H:%M:%S.%f')
+        message = log.message.replace("\\r", "\n").replace("\\n", "\n")
+        for x in message.split("\n"):
+            print(f"[{ts}] {x}")
 
 
 def truncate_datetime(value: datetime) -> Union[str, datetime]:
