@@ -5,7 +5,7 @@ import signal
 import sys
 import threading
 import time
-from typing import Any, Dict, List, Optional, Union
+from typing import Any, Dict, List, Optional
 
 from urllib3.exceptions import MaxRetryError
 
@@ -29,19 +29,8 @@ from vessl.internal.collector import (
 )
 from vessl.util import logger
 from vessl.util.api import VesslApi
-from vessl.util.audio import Audio
-from vessl.util.constant import (
-    VESSL_AUDIO_PATH,
-    VESSL_IMAGE_PATH,
-    VESSL_MEDIA_PATH,
-    VESSL_PLOTS_FILETYPE_AUDIO,
-    VESSL_PLOTS_FILETYPE_IMAGE,
-)
-from vessl.util.exception import (
-    InvalidExperimentError,
-    InvalidTypeError,
-    VesslApiException,
-)
+from vessl.util.constant import VESSL_IMAGE_PATH, VESSL_PLOTS_FILETYPE_IMAGE
+from vessl.util.exception import InvalidExperimentError, VesslApiException
 from vessl.util.image import Image
 
 MODE_TEST = "TEST"
@@ -360,16 +349,13 @@ class VesslRun(object):
             return
 
         scalar_dict = {}
-        media_dict = {}
+        image_dict = {}
 
         for k, v in payload.items():
-            if isinstance(v, list):
-                if all(isinstance(i, Image) for i in v) or all(
-                    isinstance(i, Audio) for i in v
-                ):
-                    media_dict[k] = v
-            elif isinstance(v, Image) or isinstance(v, Audio):
-                media_dict[k] = [v]
+            if isinstance(v, list) and all(isinstance(i, Image) for i in v):
+                image_dict[k] = v
+            elif isinstance(v, Image):
+                image_dict[k] = [v]
             else:
                 scalar_dict[k] = v
 
@@ -378,8 +364,8 @@ class VesslRun(object):
         if scalar_dict or step is not None:
             self._user_metric_collector.handle_step(step)
 
-        if media_dict:
-            self._update_media(media_dict)
+        if image_dict:
+            self._update_images(image_dict)
 
         if scalar_dict:
             self._update_metrics(scalar_dict)
@@ -408,31 +394,16 @@ class VesslRun(object):
             return self._user_metric_collector.step
         return self._user_metric_collector.log_metrics(payloads)
 
-    def _update_media(self, payload: Dict[str, Union[List[Image], List[Audio]]]):
-        media_type, set_media_type = None, False
+    def _update_images(self, payload: Dict[str, List[Image]]):
         path_to_caption = {}
-        for media in payload.values():
-            for medium in media:
-                path_to_caption[medium.path] = medium.caption
-                if not set_media_type:
-                    if not isinstance(medium, Image) and not isinstance(medium, Audio):
-                        raise InvalidTypeError(
-                            f"Invalid payload type error: {type(medium)}"
-                        )
-                    else:
-                        media_type = type(medium).__name__
-                        set_media_type = True
-
-        # Source image path: vessl-media/images/
-        # Source audio path: vessl-media/audio/
-        if media_type == Image.__name__:
-            source_path = os.path.join(VESSL_MEDIA_PATH, VESSL_IMAGE_PATH, "")
-        elif media_type == Audio.__name__:
-            source_path = os.path.join(VESSL_MEDIA_PATH, VESSL_AUDIO_PATH, "")
+        for images in payload.values():
+            for image in images:
+                path_to_caption[image.path] = image.caption
 
+        source_path = os.path.join(VESSL_IMAGE_PATH, "")
         assert self._experiment
         dest_volume_id = self._experiment.experiment_plot_volume
-        dest_path = "/" + VESSL_MEDIA_PATH
+        dest_path = "/"
 
         from vessl.volume import copy_volume_file
 
@@ -444,9 +415,9 @@ class VesslRun(object):
             recursive=True,
         )
 
-        for media in payload.values():
-            for medium in media:
-                medium.flush()
+        for images in payload.values():
+            for image in images:
+                image.flush()
 
         if files:
             plot_files = [
@@ -464,17 +435,13 @@ class VesslRun(object):
 
         payloads: List[ExperimentMetricEntry] = []
         for f in plot_files:
-            payload = {}
-            if media_type == Image.__name__:
-                payload = {VESSL_PLOTS_FILETYPE_IMAGE: f}
-            elif media_type == Audio.__name__:
-                payload = {VESSL_PLOTS_FILETYPE_AUDIO: f}
-            payloads.append(self._user_metric_collector.build_media_payload(payload))
+            payload = {VESSL_PLOTS_FILETYPE_IMAGE: f}
+            payloads.append(self._user_metric_collector.build_image_payload(payload))
 
         if self._mode == MODE_MANAGED:
             self._send_without_collector(payloads)
         else:
-            self._user_metric_collector.log_media(payloads)
+            self._user_metric_collector.log_images(payloads)
 
     def progress(self, value: float):
         """Update experiment progress
