@@ -2,8 +2,6 @@ import functools
 import inspect
 import os
 import time
-import logging
-import sys
 import webbrowser
 
 from openapi_client import ApiClient, APIV1Api, Configuration
@@ -21,14 +19,16 @@ from vessl.util.constant import (
     CREDENTIALS_FILE_ENV_VAR,
     DEFAULT_ORGANIZATION_ENV_VAR,
     LOGIN_TIMEOUT_SECONDS,
-    WEB_HOST, VESSL_LOG_LEVEL, VESSL_LOG_LEVEL_DEBUG,
+    VESSL_LOG_LEVEL,
+    VESSL_LOG_LEVEL_DEBUG,
+    WEB_HOST,
 )
 from vessl.util.exception import (
     GitError,
     InvalidOrganizationError,
     InvalidProjectError,
     InvalidTokenError,
-    SavvihubApiException,
+    VesslApiException,
 )
 from vessl.util.git_repo import GitRepository
 
@@ -39,7 +39,7 @@ def raise_vessl_exception(f):
         try:
             return f(*args, **kwargs)
         except ApiException as e:
-            raise SavvihubApiException.convert_api_exception(e) from None
+            raise VesslApiException.convert_api_exception(e) from None
 
     return func
 
@@ -62,6 +62,7 @@ class VesslApi(APIV1Api):
 
         for k, v in kwargs:
             _api_client.set_default_header(k, v)
+        _api_client.set_default_header("X-Source", "sdk")
         _api_client.set_default_header("X-Version", __VERSION__)
         super().__init__(_api_client)
 
@@ -80,7 +81,7 @@ class VesslApi(APIV1Api):
 
         self._initialize_git_repo()
 
-    def initialize(
+    def configure(
         self,
         *,
         access_token: str = None,
@@ -89,13 +90,13 @@ class VesslApi(APIV1Api):
         credentials_file: str = None,
         force_update_access_token: bool = False,
     ) -> None:
-        self.update_access_token(
+        self.configure_access_token(
             access_token, credentials_file, force_update_access_token
         )
-        self.update_default_organization(organization_name, credentials_file)
+        self.configure_default_organization(organization_name, credentials_file)
 
         try:
-            self.update_default_project(project_name, credentials_file)
+            self.configure_default_project(project_name, credentials_file)
         except InvalidProjectError:
             # Project is not mandatory
             return
@@ -112,7 +113,7 @@ class VesslApi(APIV1Api):
 
         try:
             webbrowser.open(url)
-        except webbrowser.Error:
+        finally:
             print(
                 f"Please grant CLI access from the URL below.\n"
                 f"{url}\n\nWaiting...\n",
@@ -217,7 +218,7 @@ class VesslApi(APIV1Api):
 
         try:
             self.user = self.get_my_user_info_api()
-        except SavvihubApiException as e:
+        except VesslApiException as e:
             self.api_client.set_default_header("Authorization", "")
             raise InvalidTokenError("Expired. Please renew your access token.")
 
@@ -270,7 +271,7 @@ class VesslApi(APIV1Api):
         self.project = projects[project_name]
         return project_name
 
-    def update_access_token(
+    def configure_access_token(
         self,
         access_token: str = None,
         credentials_file: str = None,
@@ -281,13 +282,13 @@ class VesslApi(APIV1Api):
         )
         self.config_loader.access_token = access_token
 
-    def update_default_organization(
+    def configure_default_organization(
         self, organization_name: str = None, credentials_file: str = None
     ) -> None:
         organization_name = self.set_organization(organization_name, credentials_file)
         self.config_loader.default_organization = organization_name
 
-    def update_default_project(
+    def configure_default_project(
         self, project_name: str = None, credentials_file: str = None
     ) -> None:
         project_name = self.set_project(project_name, credentials_file)
