@@ -85,12 +85,9 @@ FRAMEWORK_TYPES = (FRAMEWORK_TYPE_PYTORCH, FRAMEWORK_TYPE_TENSORFLOW)
 
 PARALLEL_WORKERS = os.environ.get("VESSL_PARALLEL_WORKERS", 20)
 
-VESSL_MEDIA_PATH = "vessl-media"
-VESSL_IMAGE_PATH = "images"
-VESSL_AUDIO_PATH = "audio"
+VESSL_IMAGE_PATH = "vessl-images"
 VESSL_PLOTS_FILETYPE_IMAGE = "image"
 VESSL_PLOTS_FILETYPE_IMAGES = "images"
-VESSL_PLOTS_FILETYPE_AUDIO = "audio"
 
 WORKSPACE_ZIP_PATH = "workspace-backup.zip"
 WORKSPACE_TEMP_ZIP_PATH = os.path.join(tempfile.gettempdir(), WORKSPACE_ZIP_PATH)
