@@ -1,16 +1,15 @@
 import os
 import tempfile
-from typing import List, Optional, Tuple
+from typing import List, Optional
 
 from openapi_client.models import (
     ProtoVolumeMountRequest,
     ProtoVolumeMountRequests,
-    ProtoVolumeMountRequestSourceDataset,
-    ProtoVolumeMountRequestSourceDatasetVersion,
     ProtoVolumeMountRequestSourceArchiveFile,
     ProtoVolumeMountRequestSourceCode,
+    ProtoVolumeMountRequestSourceDataset,
+    ProtoVolumeMountRequestSourceDatasetVersion,
     ResponseFileMetadata,
-    ResponseProjectRepository,
     VolumeFileCopyAPIPayload,
     VolumeFileCreateAPIPayload,
 )
@@ -28,8 +27,8 @@ from vessl.util.constant import (
     MOUNT_TYPE_OUTPUT,
 )
 from vessl.util.downloader import Downloader
-from vessl.util.exception import InvalidVolumeFileError, SavvihubApiException, GitError
-from vessl.util.git import get_git_repo, get_git_branch, get_git_diff_path, get_git_ref
+from vessl.util.exception import GitError, InvalidVolumeFileError, VesslApiException
+from vessl.util.git import get_git_diff_path, get_git_ref, get_git_repo
 from vessl.util.random import random_string
 from vessl.util.uploader import Uploader
 from vessl.util.zipper import Zipper
@@ -45,22 +44,25 @@ def list_volume_files(
     path: str = "",
     recursive: bool = False,
 ) -> List[ResponseFileMetadata]:
-    return vessl_api.volume_file_list_api(
+    result = vessl_api.volume_file_list_api(
         volume_id=volume_id,
         recursive=recursive,
         path=path,
         need_download_url=need_download_url,
     ).results
+    return sorted(result, key=lambda x: x.path)
 
 
 def create_volume_file(volume_id: int, is_dir: bool, path: str) -> ResponseFileMetadata:
-    return vessl_api.volume_file_create_api(
+    result = vessl_api.volume_file_create_api(
         volume_id=volume_id,
         volume_file_create_api_payload=VolumeFileCreateAPIPayload(
             is_dir=is_dir,
             path=path,
         ),
     )
+    assert isinstance(result, ResponseFileMetadata)
+    return result
 
 
 def delete_volume_file(
@@ -81,25 +83,30 @@ def copy_volume_file(
     dest_volume_id: Optional[int],
     dest_path: str,
     recursive: bool = False,
-) -> None:
-    if source_volume_id is None:
+) -> Optional[List[ResponseFileMetadata]]:
+    if source_volume_id is None and dest_volume_id:
         return _copy_volume_file_local_to_remote(
-            source_path, dest_volume_id, dest_path, recursive
+            source_path,
+            dest_volume_id,
+            dest_path,
         )
 
-    if dest_volume_id is None:
+    if dest_volume_id is None and source_volume_id:
         return _copy_volume_file_remote_to_local(
-            source_volume_id, source_path, dest_path, recursive
+            source_volume_id,
+            source_path,
+            dest_path,
         )
 
-    return _copy_volume_file_remote_to_remote(
-        source_volume_id, source_path, dest_volume_id, dest_path, recursive
-    )
+    if source_volume_id and dest_volume_id:
+        return _copy_volume_file_remote_to_remote(
+            source_volume_id, source_path, dest_volume_id, dest_path, recursive
+        )
 
 
 def _copy_volume_file_local_to_remote(
-    source_path: str, dest_volume_id: int, dest_path: str, recursive: bool
-) -> None:
+    source_path: str, dest_volume_id: int, dest_path: str
+) -> List[ResponseFileMetadata]:
     """Copy local to remote
 
     Behavior works like linux cp command
@@ -117,7 +124,7 @@ def _copy_volume_file_local_to_remote(
 
     try:
         dest_file = read_volume_file(dest_volume_id, dest_path)
-    except SavvihubApiException:
+    except VesslApiException:
         dest_file = None
 
     if not os.path.isdir(source_path):
@@ -127,7 +134,7 @@ def _copy_volume_file_local_to_remote(
         uploaded_file = Uploader.upload(source_path, dest_volume_id, dest_path)
 
         print(output.format(1, 1))
-        return uploaded_file
+        return [uploaded_file]
 
     if dest_file and not dest_file.is_dir:
         raise InvalidVolumeFileError(
@@ -145,7 +152,9 @@ def _copy_volume_file_local_to_remote(
 
 
 def _copy_volume_file_remote_to_local(
-    source_volume_id: int, source_path: str, dest_path: str, recursive: bool
+    source_volume_id: int,
+    source_path: str,
+    dest_path: str,
 ) -> None:
     """Copy remote to local
 
@@ -190,7 +199,8 @@ def _copy_volume_file_remote_to_local(
     if prefix:
         prefix += "/"
         for file in files:
-            file.path = file.path.replace(prefix, "", 1)
+            file.path = file.path.replace(prefix, "", 1)  # Remove prefix
+            file.path = os.path.normpath(file.path)
 
     downloaded_files = Downloader.bulk_download(dest_path, files)
     print(output.format(len(downloaded_files), len([x for x in files if not x.is_dir])))
@@ -220,13 +230,15 @@ def _copy_volume_file_remote_to_remote(
 
 
 def _configure_volume_mount_requests(
-    dataset_mounts: List[str],
-    git_ref_mounts: List[str],
-    git_diff_mount: str,
-    archive_file_mount: str,
-    root_volume_size: str,
-    working_dir: str,
-    output_dir: str,
+    dataset_mounts: Optional[List[str]],
+    git_ref_mounts: Optional[List[str]],
+    git_diff_mount: Optional[str],
+    local_files: Optional[List[str]],
+    upload_local_git_diff: bool,
+    archive_file_mount: Optional[str],
+    root_volume_size: Optional[str],
+    working_dir: Optional[str],
+    output_dir: Optional[str],
     **kwargs,
 ) -> ProtoVolumeMountRequests:
     requests = [
@@ -234,13 +246,16 @@ def _configure_volume_mount_requests(
         _configure_volume_mount_request_output(output_dir),
     ]
 
-    if git_ref_mounts is None and git_diff_mount is None and archive_file_mount is None:
+    if local_files:
+        requests.extend(_configure_volume_mount_request_local_files(local_files, **kwargs))
+
+    if not git_ref_mounts and git_diff_mount is None and archive_file_mount is None:
         # No information for code mount is given - user is creating new experiment from CLI.
         # Generate VolumeMountRequest from projectRepository and local working directory
-        requests.extend(_configure_volume_mount_request_local(**kwargs))
+        requests.extend(_configure_volume_mount_request_local_git(upload_local_git_diff, **kwargs))
     else:
         # Explicit information for code mount is given - user is reproducing experiment from CLI.
-        if git_ref_mounts is not None:
+        if not git_ref_mounts:
             requests.extend(
                 _configure_volume_mount_request_codes(
                     git_ref_mounts, git_diff_mount, **kwargs
@@ -314,49 +329,25 @@ def _configure_volume_mount_request_dataset(
     )
 
 
-def _configure_volume_mount_request_local(**kwargs) -> List[ProtoVolumeMountRequest]:
+def _configure_volume_mount_request_local_files(local_files: List[str], **kwargs) -> List[ProtoVolumeMountRequest]:
     project = _get_project(**kwargs)
 
-    local_git_owner, local_git_repo = None, None
-    local_repo_is_project_repository = False
-    try:
-        local_git_owner, local_git_repo = get_git_repo()
-    except GitError:
-        pass
-
     volume_mount_requests: List[ProtoVolumeMountRequest] = []
-    used_mount_pathes = set()
-    for repo in project.project_repositories:
-        mount_path = f"/home/vessl/{repo.git_repo}"
-        if mount_path in used_mount_pathes:
-            mount_path = f"/home/vessl/{repo.git_repo}-{repo.git_owner}"
+    for local_file in local_files:
+        if ":" in local_file:
+            local_path, remote_path = local_file.split(":")
+            if not os.path.isabs(remote_path):
+                remote_path = os.path.join("/home/vessl", remote_path)
+        else:
+            local_path = local_file
+            remote_path = "/home/vessl/local"
 
-        git_mount_info = f"github/{repo.git_owner}/{repo.git_repo}/latest"
-        git_diff_path = None
-        if repo.git_owner == local_git_owner and repo.git_repo == local_git_repo:
-            # Current working directory is one of the project repository.
-            # Mount VolumeSourceCode with potential uncommitted changes
-            local_repo_is_project_repository = True
-            git_diff_path = get_git_diff_path(project)
-            git_mount_info = git_mount_info.replace("latest", get_git_ref())
-        volume_mount_requests.append(
-            _configure_volume_mount_request_code(
-                git_ref_mount=f"{mount_path}:{git_mount_info}",
-                git_diff_mount=None
-                if git_diff_path is None
-                else f"{mount_path}:{git_diff_path}",
-            )
-        )
-
-    if not local_repo_is_project_repository:
-        # Current working directory is not a known git directory.
-        # Mount whole directory as a VolumeSourceArchivedFile
-        cwd = os.path.abspath(os.getcwd())
+        cwd = os.path.abspath(local_path)
         zip_path = os.path.abspath(
             os.path.join(tempfile.gettempdir(), f"{project.name}_{random_string()}.zip")
         )
         zipper = Zipper(zip_path, "w")
-        zipper.zipdir(cwd, zipper)
+        zipper.zip(cwd, zipper)
         zipper.close()
 
         uploaded = Uploader.upload(
@@ -367,7 +358,42 @@ def _configure_volume_mount_request_local(**kwargs) -> List[ProtoVolumeMountRequ
         os.remove(zipper.filename)
         volume_mount_requests.append(
             _configure_volume_mount_request_archive_file(
-                archive_file_mount=f"/home/vessl/local:{uploaded.path}"
+                archive_file_mount=f"{remote_path}:{uploaded.path}"
+            )
+        )
+
+    return volume_mount_requests
+
+
+def _configure_volume_mount_request_local_git(upload_local_git_diff, **kwargs) -> List[ProtoVolumeMountRequest]:
+    project = _get_project(**kwargs)
+
+    local_git_owner, local_git_repo = None, None
+    try:
+        local_git_owner, local_git_repo = get_git_repo()
+    except GitError:
+        pass
+
+    volume_mount_requests: List[ProtoVolumeMountRequest] = []
+    used_mount_paths = set()
+    for repo in project.project_repositories:
+        mount_path = f"/home/vessl/{repo.git_repo}"
+        if mount_path in used_mount_paths:
+            mount_path = f"/home/vessl/{repo.git_repo}-{repo.git_owner}"
+
+        git_mount_info = f"github/{repo.git_owner}/{repo.git_repo}/latest"
+        git_diff_path = None
+        if upload_local_git_diff and repo.git_owner == local_git_owner and repo.git_repo == local_git_repo:
+            # Current working directory is one of the project repository.
+            # Mount VolumeSourceCode with potential uncommitted changes
+            git_diff_path = get_git_diff_path(project)
+            git_mount_info = git_mount_info.replace("latest", get_git_ref())
+        volume_mount_requests.append(
+            _configure_volume_mount_request_code(
+                git_ref_mount=f"{mount_path}:{git_mount_info}",
+                git_diff_mount=None
+                if git_diff_path is None
+                else f"{mount_path}:{git_diff_path}",
             )
         )
 
